==> sale-1.11.14-14.jar: revenue/sqls/revenue/eticket/eticketRecordList.sql <==
 select *from (   select
        s.id,--业务id
        s.f_pregas, --预购气量
        s.f_preamount,--预购气费
        u.f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        s.f_charge_state,
        u.f_user_name,
        s.f_bill_style,
        e.f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_invoice_type='1' then '冲红' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeids,e.f_sign_url
    From  t_eticketrelated tick
    left join t_sellinggas s
    on s.id= tick.f_sell_id
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on u.f_userinfo_id=s.f_userinfo_id
    left join t_user_address address
    on u.f_Userinfo_id=address.f_userinfo_id
    union all
    select
        s.id,--业务id
        0 f_pregas , --预购气量
        0 f_preamount ,--预购气费
        u.f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        s.f_changemeter_state f_charge_state,
        u.f_user_name,
        s.f_bill_style,
        e.f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_invoice_type='1' then '冲红' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeids,e.f_sign_url
    From  t_eticketrelated tick
    left join t_changemeter s
    on s.id= tick.f_sell_id
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on u.f_userinfo_id=s.f_userinfo_id
    left join t_user_address address
    on u.f_Userinfo_id=address.f_userinfo_id
    union all
    select
        s.id,--业务id
        s.f_number  f_pregas , --数量
        s.f_collection f_preamount ,--金额
        u.f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        s.f_charge_state,
        u.f_user_name,
        s.f_bill_style,
        e.f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_invoice_type='1' then '冲红' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeids,e.f_sign_url
    From  t_eticketrelated tick
    left join t_othercharge s
    on s.id= tick.f_sell_id
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on u.f_userinfo_id=s.f_userinfo_id
    left join t_user_address address
    on u.f_Userinfo_id=address.f_userinfo_id
 union all
    select
        s.id,--业务id
        '1'  f_pregas , --数量
        s.f_cardfees f_preamount ,--金额
        u.f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        s.f_fillcard_state f_charge_state,
        u.f_user_name,
        s.f_bill_style,
        e.f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_invoice_type='1' then '冲红' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeids,e.f_sign_url
    From  t_eticketrelated tick
    left join t_fillcard s
    on s.id= tick.f_sell_id
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on u.f_userinfo_id=s.f_userinfo_id
    left join t_user_address address
    on u.f_Userinfo_id=address.f_userinfo_id
    union all
    select
        s.id,--业务id
        s.f_fillgas  f_pregas , --数量
        s.f_fillgas_fee f_preamount ,--金额
        u.f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        s.f_fillgas_state f_charge_state,
        u.f_user_name,
        '电子发票' f_bill_style,
        e.f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_invoice_type='1' then '冲红' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeids,e.f_sign_url
    From  t_eticketrelated tick
    left join t_fillgas s
    on s.id= tick.f_sell_id
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on u.f_userinfo_id=s.f_userinfo_id
    left join t_user_address address
    on u.f_Userinfo_id=address.f_userinfo_id
union all
    select
        e.id,--业务id
        '0'  f_pregas , --数量
        e.f_total_money f_preamount ,--金额
        u.f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        '有效' f_charge_state,
        u.f_user_name,
        '电子发票' f_bill_style,
        e.f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_invoice_type='1' then '冲红' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeids,e.f_sign_url
    From  (select f_eticket_id From t_eticketrelated where f_business_type='物联网结算' or f_business_type='卡表结算'  group by f_sell_id,f_eticket_id  )tick
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on u.f_userinfo_id=e.f_userinfo_id
    left join t_user_address address
    on u.f_Userinfo_id=address.f_userinfo_id
)t
where {condition} and f_bill_style='电子发票' and f_charge_state<>'无效'
order by  f_kprq desc

==> sale-1.11.14-16.jar: revenue/sqls/revenue/eticket/eticketRecordList.sql <==
 select *from (   select
        s.id,--业务id
        s.f_pregas, --预购气量
        s.f_preamount,--预购气费
        isnull(u.f_userinfo_code,'')f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        s.f_charge_state,
        u.f_user_name,
        s.f_bill_style,
        s.f_delivery_date f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_bill_state='有效' then '开票失败' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeid,e.f_sign_url,e.f_orgstr,s.f_payment,e.f_red_info_code,e.f_corresponding_red_code
    From  t_eticketrelated tick
    left join t_sellinggas s
    on s.id= tick.f_sell_id
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on u.f_userinfo_id=s.f_userinfo_id
    left join t_user_address address
    on u.f_Userinfo_id=address.f_userinfo_id
    union all
    select
        s.id,--业务id
        0 f_pregas , --预购气量
        0 f_preamount ,--预购气费
        isnull(u.f_userinfo_code,'')f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        s.f_changemeter_state f_charge_state,
        u.f_user_name,
        s.f_bill_style,
        s.f_changemeter_date f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_bill_state='有效' then '开票失败' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeid,e.f_sign_url,e.f_orgstr,''f_payment,e.f_red_info_code,e.f_corresponding_red_code
    From  t_eticketrelated tick
    left join t_changemeter s
    on s.id= tick.f_sell_id
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on u.f_userinfo_id=s.f_userinfo_id
    left join t_user_address address
    on u.f_Userinfo_id=address.f_userinfo_id
    union all
    select
        s.id,--业务id
        s.f_number  f_pregas , --数量
        s.f_collection f_preamount ,--金额
        isnull(u.f_userinfo_code,'')f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        s.f_charge_state,
        u.f_user_name,
        s.f_bill_style,
        s.f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_bill_state='有效' then '开票失败' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeid,e.f_sign_url,e.f_orgstr,s.f_payment,e.f_red_info_code,e.f_corresponding_red_code
    From  t_eticketrelated tick
    left join t_othercharge s
    on s.id= tick.f_sell_id
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on u.f_userinfo_id=s.f_userinfo_id
    left join t_user_address address
    on u.f_Userinfo_id=address.f_userinfo_id
 union all
    select
        s.id,--业务id
        '1'  f_pregas , --数量
        s.f_cardfees f_preamount ,--金额
        isnull(u.f_userinfo_code,'')f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        s.f_fillcard_state f_charge_state,
        u.f_user_name,
        s.f_bill_style,
        s.f_fillcard_date f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_bill_state='有效' then '开票失败' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeid,e.f_sign_url,e.f_orgstr,''f_payment,e.f_red_info_code,e.f_corresponding_red_code
    From  t_eticketrelated tick
    left join t_fillcard s
    on s.id= tick.f_sell_id
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on cast(u.f_userinfo_id as varchar)= cast(s.f_userinfo_id as varchar)
    left join t_user_address address
    on cast(u.f_Userinfo_id as varchar)=cast (address.f_userinfo_id as varchar)
    union all
    select
        s.id,--业务id
        s.f_fillgas  f_pregas , --数量
        s.f_fillgas_fee f_preamount ,--金额
        isnull(u.f_userinfo_code,'')f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        s.f_fillgas_state f_charge_state,
        u.f_user_name,
        '电子发票' f_bill_style,
        s.f_fillgas_date f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_bill_state='有效' then '开票失败' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeid,e.f_sign_url,e.f_orgstr,''f_payment,e.f_red_info_code,e.f_corresponding_red_code
    From  t_eticketrelated tick
    left join t_fillgas s
    on s.id= tick.f_sell_id
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on cast(u.f_userinfo_id as varchar)= cast(s.f_userinfo_id as varchar)
    left join t_user_address address
    on cast(u.f_Userinfo_id as varchar)=cast (address.f_userinfo_id as varchar)
union all
    select
        e.id,--业务id
        '0'  f_pregas , --数量
        e.f_total_money f_preamount ,--金额
        isnull(u.f_userinfo_code,'')f_userinfo_code,
        address.f_address,
        e.id f_eticket_id,
        '有效' f_charge_state,
        u.f_user_name,
        '电子发票' f_bill_style,
        e.f_operate_date,
        case when e.f_tax_logotype='0' then '不征税'
            when e.f_tax_logotype='1' then '征税'
               end f_tax_logotype,
        e.f_charge_type,--业务类型
        e.f_total_money,--合计金额
        e.f_tax_money,--税后金额
        e.f_bill_code,--发票代码
        e.f_bill_number,--发票号码
        case when e.f_bill_state='有效' then '开票失败' else e.f_bill_state end f_bill_state,
        e.f_issue_status,--开局状态
        e.f_kprq,e.f_filialeid,e.f_sign_url,e.f_orgstr,''f_payment,e.f_red_info_code,e.f_corresponding_red_code
    From  (select f_eticket_id From t_eticketrelated where f_business_type='物联网结算' or f_business_type='卡表结算'  group by f_eticket_id  )tick
    left join t_eticket e
    on tick.f_eticket_id=e.id
    left join t_userinfo u
    on u.f_userinfo_id=e.f_userinfo_id
    left join t_user_address address
    on u.f_Userinfo_id=address.f_userinfo_id
)t
where   {condition} and f_charge_state<>'无效' and f_bill_state !='无效'
order by  f_kprq desc
